Class: Aws::CodeConnections::Types::ListHostsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codeconnections/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#hostsArray<Types::Host>

A list of hosts and the details for each host, such as status, endpoint, and provider type.

Returns:



847
848
849
850
851
852
# File 'lib/aws-sdk-codeconnections/types.rb', line 847

class ListHostsOutput < Struct.new(
  :hosts,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that can be used in the next ListHosts call. To view all items in the list, continue to call this operation with each subsequent token until no more nextToken values are returned.

Returns:

  • (String)


847
848
849
850
851
852
# File 'lib/aws-sdk-codeconnections/types.rb', line 847

class ListHostsOutput < Struct.new(
  :hosts,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end